@@ -80,8 +80,11 @@ class ResonantGeoDataBaseMixin(GeoDjangoMixin, SwaggerMixin, ConfigMixin):
             'rest_framework.authentication.TokenAuthentication',
         ]
 
-        if getattr(configuration, 'DEBUG', False):
-            configuration.LOGGING['loggers']['rgd'] = {
+    @classmethod
+    def post_setup(cls):
+        super().post_setup()
+        if getattr(cls, 'DEBUG', False) or cls.RGD_DEBUG_LOGS:
+            cls.LOGGING['loggers']['rgd'] = {
                 'level': 'DEBUG',
                 'handlers': ['console'],
                 'propagate': False,
@@ -110,3 +113,4 @@ class ResonantGeoDataBaseMixin(GeoDjangoMixin, SwaggerMixin, ConfigMixin):
     RGD_REST_CACHE_TIMEOUT = values.Value(default=60 * 60 * 2)
     RGD_SIGNED_URL_TTL = values.Value(default=60 * 60 * 24)  # 24 hours
     RGD_SIGNED_URL_QUERY_PARAM = values.Value(default='signature')
+    RGD_DEBUG_LOGS = values.Value(default=True)
